# This file is part of ROBOTGAME
#
# ROBOTGAME is free software: you can redistribute it and/or modify it under the
# terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# ROBOTGAME is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# ROBOTGAME.  If not, see <http://www.gnu.org/licenses/>.
#
# ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' '
#
#                           level1.py
#                     --------------------
#       date created : Tue Aug 7 2012
#          copyright : (C) 2012 Sakse Dalum
#      maintained by : Sakse Dalum <don_s@hongabar.org>

"""
The first level.
"""

import os
import pygame

import level
import player
import tile

class Level1(level.Level):
    def __init__(self, graphics_dir):
        self.__dict__.update(locals())

        self.player = player.Player(200, 200)

        self.tiles = []
        self.imgs = {}

        self.load()

        for i in range(0, 10):
            for j in range(0, 10):
                self.tiles.append(
                    tile.Tile(i*64, j*48,
                              self.imgs['ground%d' % (((i + j) % 2) + 1)]))

    def load(self):
        """Load all resources used in the level."""
        tile_list = ['ground1', 'ground2']

        for tile in tile_list:
            self.imgs[tile] = pygame.image.load(os.path.join(
                    self.graphics_dir, 'tiles', '%s.png' % tile))

    def update(self, e, t, dt):
        self.player.update(e, t, dt)

    def draw(self, window):
        for tile in self.tiles:
            tile.draw(window)

        self.player.draw(window)
